@@ -715,11 +715,41 @@ impl<'a> RtLolaParser<'a> {
                                                 "∀" | "conjunction" | "∧" | "forall" => {
                                                     WindowOperation::Conjunction
                                                 }
+                                                "last" => WindowOperation::Last,
+                                                "variance" | "var" | "σ²" => WindowOperation::Variance,
+                                                "covariance" | "cov" => WindowOperation::Covariance,
+                                                "standard_deviation" | "sd" | "σ" => WindowOperation::StandardDeviation,
+                                                "median" | "med" | "µ" => WindowOperation::NthPercentile(50),
+                                                _ if i.name.as_str().starts_with("pctl") &&
+                                                    i.name.as_str().chars().skip("pctl".len()).all(|c| c.is_numeric()) => {
+                                                    let n_string = i.name.as_str().to_string();
+                                                    let n_string: String = n_string.chars().skip("pctl".len()).collect();
+                                                    let percentile: usize = match n_string.parse::<usize>() {
+                                                        Ok(u) => u,
+                                                        Err(_e) => {
+                                                            self.handler.error_with_span(
+                                                                &format!("unknown aggregation function {}, invalid number-percentile suffix {}", i.name, n_string),
+                                                                i.span.clone(),
+                                                                Some("available: count, min, max, sum, average, exists, forall, integral, last, variance, covariance, standard_deviation, median, pctlX with 0 ≤ X ≤ 100 (e.g. pctl25)"),
+                                                            );
+                                                            std::process::exit(1)
+                                                        }
+                                                    };
+                                                    if percentile > 100{
+                                                        self.handler.error_with_span(
+                                                            &format!("unknown aggregation function {}, invalid percentile suffix", i.name),
+                                                            i.span.clone(),
+                                                            Some("available: count, min, max, sum, average, exists, forall, integral, last, variance, covariance, standard_deviation, median, pctlX with 0 ≤ X ≤ 100 (e.g. pctl25)"),
+                                                        );
+                                                        std::process::exit(1);
+                                                    }
+                                                    WindowOperation::NthPercentile(percentile as u8)
+                                                }
                                                 fun => {
                                                     self.handler.error_with_span(
                                                         &format!("unknown aggregation function {}", fun),
                                                         i.span.clone(),
-                                              Some("available: count, min, max, sum, average, exists, forall, integral"),
+                                              Some("available: count, min, max, sum, average, exists, forall, integral, last, variance, covariance, standard_deviation, median, pctlX with 0 ≤ X ≤ 100 (e.g. pctl25)"),
                                                     );
                                                     std::process::exit(1);
                                                 }
@@ -728,12 +758,19 @@ impl<'a> RtLolaParser<'a> {
                                                 self.handler.error_with_span(
                                                     "expected aggregation function",
                                                     args[1].span.clone(),
-                                                    Some("available: count, min, max, sum, average, integral"),
+                                                    Some("available: count, min, max, sum, average, exists, forall, integral, last, variance, covariance, standard_deviation, median, pctlX with 0 ≤ X ≤ 100 (e.g. pctl25)"),
                                                 );
                                                 std::process::exit(1);
                                             }
                                         };
                                         if signature.contains("discrete") {
+                                            if window_op == WindowOperation::Last {
+                                                self.handler.warn_with_span(
+                                                    "discrete window operation: last has same semantics as .offset(by:-1) and is more expensive",
+                                                    args[1].span.clone(),
+                                                    Some("don't use last for discrete windows")
+                                                )
+                                            }
                                             ExpressionKind::DiscreteWindowAggregation {
                                                 expr: inner,
                                                 duration: Box::new(args[0].clone()),
@@ -1478,6 +1515,13 @@ mod tests {
         assert_eq!(handler.emitted_errors(), 1);
     }
 
+    #[test]
+    fn valid_percentile() {
+        let spec = "output x := x.aggregate(over: 3s, using: pctl15)\n";
+        let ast = parse(spec);
+        cmp_ast_spec(&ast, spec);
+    }
+
     #[test]
     fn spawn_with_pacing() {
         let spec = "output x spawn @3Hz with (x) if true := 5\n";
